@@ -1,9 +1,9 @@
-from .NLG.rouge import ROUGEScorer
+from .NLG.rouge.rouge import Rouge, Rouge1, Rouge2, RougeL
+from .NLG.bleu.bleu import Bleu
+from .NLG.meteor.meteor import Meteor
+from .NLG.ciderD.ciderD import CiderD
 from .NLG.mauve_ import MauveScorer
-from .NLG.bleu.bleu import BLEUScorer
-from .NLG.meteor.meteor import METEORScorer
-from .NLG.cider.cider import Cider
-from .NLG.ciderd.ciderd import CiderD
+from .NLG.ciderD_RL.ciderD_RL import CiderDRL
 from .CheXbert.chexbert import CheXbert
 from .RadEntityMatchExact.RadEntityMatchExact import RadEntityMatchExact
 from .RadEntityNLI.RadEntityNLI import RadEntityNLI
